@@ -14,27 +14,10 @@ describe("transformSchema", () => {
 
     # https://github.com/apollographql/apollo-tooling/issues/2162
     directive @test(baz: DirectiveArg) on FIELD_DEFINITION
-
-    interface FooInterface {
-      foo: String
-    }
-
-    interface BarInterface implements FooInterface {
-      foo: String
-      bar: Boolean
-    }
-
-    type FooBarBazType implements FooInterface & BarInterface {
-      foo: String
-      bar: Boolean
-      baz: Float
-    }
     `);
 
-    const originalSDL = printSchema(schema);
     const newSchema = transformSchema(schema, namedType => namedType);
 
-    expect(printSchema(schema)).toEqual(originalSDL);
-    expect(printSchema(newSchema)).toEqual(originalSDL);
+    expect(printSchema(newSchema)).toEqual(printSchema(schema));
   });
 });
